==> VE-SDK-0.5.0.zip: org/eclipse/ve/internal/java/codegen/java/rules/IfStatementRule.java <==
package org.eclipse.ve.internal.java.codegen.java.rules;
/*******************************************************************************
 * Copyright (c) 2001, 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
/*
 *  $RCSfile: IfStatementRule.java,v $
 *  $Revision: 1.1 $  $Date: 2003/10/27 17:48:30 $ 
 */

import org.eclipse.jdt.internal.compiler.ast.AbstractMethodDeclaration;
import org.eclipse.jdt.internal.compiler.ast.IfStatement;
import org.eclipse.ve.internal.cde.rules.IRuleRegistry;

import org.eclipse.ve.internal.java.codegen.java.ISourceVisitor;
import org.eclipse.ve.internal.java.codegen.model.IBeanDeclModel;

public class IfStatementRule implements IIfStatementRule {

	/**
	 *  No Overide
	 */
	public ISourceVisitor overideIFVisit(AbstractMethodDeclaration method, IfStatement stmt, IBeanDeclModel model) {
		return null;
	}

	/**
	 *  We can try to use some pattern analysys.  e.g., VAJ's initialization as 
	 *  if (ivjFoo == null) {  initialize block }
	 */
	public int whichPartToProcess(AbstractMethodDeclaration method, IfStatement stmt) {
		// This will do for now,
		return PROCESS_IF;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ve.internal.cde.rules.IRule#setRegistry(org.eclipse.ve.internal.cde.rules.IRuleRegistry)
	 */
	public void setRegistry(IRuleRegistry registry) {
		// no-op. We don't care.
	}
}

==> VE-SDK-1.0.2.2.zip: org/eclipse/ve/internal/java/codegen/java/rules/IfStatementRule.java <==
/*******************************************************************************
 * Copyright (c) 2001, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.ve.internal.java.codegen.java.rules;
/*
 *  $RCSfile: IfStatementRule.java,v $
 *  $Revision: 1.3 $  $Date: 2004/08/27 15:34:10 $ 
 */


import org.eclipse.jdt.core.dom.IfStatement;
import org.eclipse.jdt.core.dom.MethodDeclaration;

import org.eclipse.ve.internal.cde.rules.IRuleRegistry;

import org.eclipse.ve.internal.java.codegen.java.ISourceVisitor;
import org.eclipse.ve.internal.java.codegen.model.IBeanDeclModel;

public class IfStatementRule implements IIfStatementRule {

	/**
	 *  No Overide
	 */
	public ISourceVisitor overideIFVisit(MethodDeclaration method, IfStatement stmt, IBeanDeclModel model) {
		return null;
	}

	/**
	 *  We can try to use some pattern analysys.  e.g., VAJ's initialization as 
	 *  if (ivjFoo == null) {  initialize block }
	 */
	public int whichPartToProcess(MethodDeclaration method, IfStatement stmt) {
		// This will do for now,
		return PROCESS_IF;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ve.internal.cde.rules.IRule#setRegistry(org.eclipse.ve.internal.cde.rules.IRuleRegistry)
	 */
	public void setRegistry(IRuleRegistry registry) {
		// no-op. We don't care.
	}
}
